# Contributing to django-rest-xauth

An introduction to contributing to the django-rest-xauth project.

The django-rest-xauth project welcomes, and depends, on contributions from developers and users in the open source
community. Contributions can be made in a number of ways, a few examples are:

- Code patches via pull requests.
- Documentation improvements.
- Bug reports and patch reviews.

## Reporting an Issue

Please include as much detail as you can. Let us know your platform and django-rest-xauth version. If the problem is
visual (for example a theme or design issue) please add a screenshot and if you get an error please include the full
error and traceback.

## Submitting Pull Requests

Once you are happy with your changes, or you are ready for some feedback, push it to your fork and send a pull request.
For a change to be accepted it will most likely need to have tests and documentation if it is a new feature.
